@@ -14,38 +14,38 @@
 #include "dbaccess.h"
 #include "tagpropertiesdialog.h"
 
-#include <AkonadiCore/TagFetchScope>
-#include <AkonadiCore/attributefactory.h>
-#include <AkonadiCore/changerecorder.h>
-#include <AkonadiCore/collectionfilterproxymodel.h>
-#include <AkonadiCore/entitymimetypefiltermodel.h>
-#include <AkonadiCore/favoritecollectionsmodel.h>
-#include <AkonadiCore/itemfetchjob.h>
-#include <AkonadiCore/itemfetchscope.h>
-#include <AkonadiCore/itemmodifyjob.h>
-#include <AkonadiCore/job.h>
-#include <AkonadiCore/selectionproxymodel.h>
-#include <AkonadiCore/session.h>
-#include <AkonadiCore/statisticsproxymodel.h>
-#include <AkonadiCore/tagdeletejob.h>
-#include <AkonadiCore/tagmodel.h>
-#include <AkonadiWidgets/collectionpropertiesdialog.h>
-#include <AkonadiWidgets/controlgui.h>
-#include <AkonadiWidgets/entitylistview.h>
-#include <AkonadiWidgets/entitytreeview.h>
-#include <AkonadiWidgets/standardactionmanager.h>
-#include <AkonadiXml/XmlWriteJob>
+#include <Akonadi/AttributeFactory>
+#include <Akonadi/ChangeRecorder>
+#include <Akonadi/CollectionFilterProxyModel>
+#include <Akonadi/CollectionPropertiesDialog>
+#include <Akonadi/ControlGui>
+#include <Akonadi/EntityListView>
+#include <Akonadi/EntityMimeTypeFilterModel>
+#include <Akonadi/EntityTreeView>
+#include <Akonadi/FavoriteCollectionsModel>
+#include <Akonadi/ItemFetchJob>
+#include <Akonadi/ItemFetchScope>
+#include <Akonadi/ItemModifyJob>
+#include <Akonadi/Job>
+#include <Akonadi/SelectionProxyModel>
+#include <Akonadi/Session>
+#include <Akonadi/StandardActionManager>
+#include <Akonadi/StatisticsProxyModel>
+#include <Akonadi/TagDeleteJob>
+#include <Akonadi/TagFetchScope>
+#include <Akonadi/TagModel>
+#include <Akonadi/XmlWriteJob>
 #include <KViewStateMaintainer>
 #include <akonadi/private/compressionstream_p.h>
 
 #include <KCalendarCore/ICalFormat>
 #include <KCalendarCore/Incidence>
-#include <kcontacts/addressee.h>
-#include <kcontacts/contactgroup.h>
+#include <KContacts/Addressee>
+#include <KContacts/ContactGroup>
 
 #include "akonadiconsole_debug.h"
-#include <AkonadiCore/tagcreatejob.h>
-#include <AkonadiCore/tagmodifyjob.h>
+#include <Akonadi/TagCreateJob>
+#include <Akonadi/TagModifyJob>
 #include <KActionCollection>
 #include <KConfig>
 #include <KConfigGroup>
