@@ -11,14 +11,17 @@
 #include "libakonadiconsole_export.h"
 #include <QAbstractItemModel>
 
+#include <memory>
+
 class JobTracker;
+class JobTrackerModelPrivate;
 
 class LIBAKONADICONSOLE_EXPORT JobTrackerModel : public QAbstractItemModel
 {
     Q_OBJECT
 public:
     explicit JobTrackerModel(const char *name, QObject *parent = nullptr);
-    virtual ~JobTrackerModel();
+    ~JobTrackerModel() override;
 
     JobTracker &jobTracker(); // for the unittest
 
@@ -55,7 +58,6 @@ private Q_SLOTS:
     void jobsUpdated(const QList<QPair<int, int>> &);
 
 private:
-    class Private;
-    Private *const d;
+    std::unique_ptr<JobTrackerModelPrivate> const d;
 };
 
