@@ -10,15 +10,19 @@
 
 #include <QWidget>
 
+#include <memory>
+
 class QModelIndex;
 class QFile;
+class JobTrackerWidgetPrivate;
+
 class JobTrackerWidget : public QWidget
 {
     Q_OBJECT
 
 public:
     explicit JobTrackerWidget(const char *name, QWidget *parent, const QString &checkboxText);
-    ~JobTrackerWidget();
+    ~JobTrackerWidget() override;
 private Q_SLOTS:
     void contextMenu(const QPoint &pos);
     void slotSaveToFile();
@@ -32,7 +36,7 @@ private:
     void textFilterChanged(const QString &str);
     void writeRows(const QModelIndex &parent, QFile &file, int indentLevel);
 
-    class Private;
-    Private *const d;
+private:
+    std::unique_ptr<JobTrackerWidgetPrivate> const d;
 };
 
