@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AKONADICONSOLE_LOGGINGMODEL_H_
-#define AKONADICONSOLE_LOGGINGMODEL_H_
+#pragma once
 
 #include <QAbstractItemModel>
 #include <QSet>
@@ -79,4 +78,3 @@ private:
     QSet<QString> mFunctionCache;
 };
 
-#endif
