@@ -8,7 +8,7 @@
 #pragma once
 
 #include "libakonadiconsole_export.h"
-#include <AkonadiCore/NotificationSubscriber>
+#include <Akonadi/NotificationSubscriber>
 #include <QAbstractItemModel>
 
 namespace Akonadi
@@ -24,7 +24,7 @@ public:
     enum Roles { SubscriberRole = Qt::UserRole };
 
     explicit MonitorsModel(QObject *parent = nullptr);
-    virtual ~MonitorsModel();
+    ~MonitorsModel() override;
 
     void setEnabled(bool enabled);
 
