@@ -6,10 +6,9 @@
 
 #include "notificationmodel.h"
 
-#include <QLocale>
 
 #include "akonadiconsole_debug.h"
-#include <AkonadiCore/ServerManager>
+#include <Akonadi/ServerManager>
 
 #include <QMetaMethod>
 #include <akonadi/private/imapparser_p.h>
