@@ -8,8 +8,8 @@
 
 #include <QAbstractItemModel>
 
-#include <AkonadiCore/ChangeNotification>
-#include <AkonadiCore/Monitor>
+#include <Akonadi/ChangeNotification>
+#include <Akonadi/Monitor>
 
 namespace Akonadi
 {
@@ -36,7 +36,7 @@ public:
     };
 
     explicit NotificationModel(QObject *parent);
-    ~NotificationModel();
+    ~NotificationModel() override;
 
     int columnCount(const QModelIndex &parent = QModelIndex()) const override;
     int rowCount(const QModelIndex &parent = QModelIndex()) const override;
