@@ -23,8 +23,8 @@
 #include <QDBusArgument>
 #include <QDBusConnection>
 
-#include <AkonadiCore/servermanager.h>
-#include <AkonadiWidgets/controlgui.h>
+#include <Akonadi/ControlGui>
+#include <Akonadi/ServerManager>
 
 #include <KColorScheme>
 
@@ -95,7 +95,7 @@ private:
     class TransactionNode : public QueryNode
     {
     public:
-        ~TransactionNode()
+        ~TransactionNode() override
         {
             qDeleteAll(queries);
         }
@@ -108,7 +108,7 @@ private:
     class ConnectionNode : public Node
     {
     public:
-        ~ConnectionNode()
+        ~ConnectionNode() override
         {
             qDeleteAll(queries);
         }
@@ -125,7 +125,7 @@ public:
     {
     }
 
-    ~QueryTreeModel()
+    ~QueryTreeModel() override
     {
         qDeleteAll(mConnections);
     }
