@@ -11,11 +11,11 @@
 #include "akonadiconsole_debug.h"
 #include "searchwidget.h"
 
-#include <AkonadiCore/SearchQuery>
-#include <AkonadiCore/itemfetchjob.h>
-#include <AkonadiCore/itemfetchscope.h>
-#include <AkonadiCore/itemsearchjob.h>
-#include <AkonadiWidgets/controlgui.h>
+#include <Akonadi/ControlGui>
+#include <Akonadi/ItemFetchJob>
+#include <Akonadi/ItemFetchScope>
+#include <Akonadi/ItemSearchJob>
+#include <Akonadi/SearchQuery>
 
 #include <AkonadiSearch/Core/searchstore.h>
 #include <AkonadiSearch/Xapian/xapiansearchstore.h>
@@ -101,7 +101,7 @@ SearchWidget::SearchWidget(QWidget *parent)
 
     connect(button, &QPushButton::clicked, this, &SearchWidget::search);
     connect(mDatabaseView, &QListView::activated, this, &SearchWidget::fetchItem);
-    connect(mStoreCombo, QOverload<int>::of(&KComboBox::currentIndexChanged), this, &SearchWidget::openStore);
+    connect(mStoreCombo, &KComboBox::currentIndexChanged, this, &SearchWidget::openStore);
 
     openStore(0);
 
